<template>
  <div>
    <el-form ref="form" :model="form" label-width="80px" :disabled="true">
      <el-form-item label="部署名称" prop="deploymentName">
        <el-input v-model="form.deploymentName" maxlength="64" show-word-limit placeholder="请输入部署名称"/>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="LAN" prop="lan">
            <el-input v-model="form.lan" placeholder="请输入LAN"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="IP" prop="ip">
            <el-input v-model="form.ip" placeholder="请输入IP"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="操作系统" prop="operatingSystem">
            <el-select v-model="form.operatingSystem" placeholder="请选择操作系统">
              <el-option
                  v-for="dict in dict.type.DICT115"
                  :key="dict.value"
                  :label="dict.label"
                  :value="dict.value"
              ></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="账户" prop="account">
            <el-input v-model="form.account" maxlength="64" show-word-limit placeholder="请输入账户"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="部署位置" prop="buildingId">
        <building v-model="form.buildingId"></building>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="机柜号" prop="cabinetNumber">
            <el-input v-model="form.cabinetNumber" maxlength="64" show-word-limit placeholder="请输入机柜号"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="机架号" maxlength="64" show-word-limit prop="rackNumber">
            <el-input v-model="form.rackNumber" maxlength="64" show-word-limit placeholder="请输入机架号"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="所属单位" prop="organizationId">
        <organization v-model="form.organizationId"></organization>
      </el-form-item>
      <el-form-item label="施工批次" prop="constructionBatchId">
        <constructionBatch v-model="form.constructionBatchId"></constructionBatch>
      </el-form-item>
      <el-form-item label="序列号" prop="serialNumber">
        <el-input v-model="form.serialNumber" maxlength="64" show-word-limit placeholder="请输入序列号"/>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="型号" prop="model">
            <el-input v-model="form.model" maxlength="64" show-word-limit placeholder="请输入型号"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="生产厂商" prop="manufacturerId">
            <manufacturer v-model="form.manufacturerId"></manufacturer>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="性能指标" prop="performanceIndex">
        <el-input v-model="form.performanceIndex" type="textarea" :rows="8" maxlength="64" show-word-limit
                  placeholder="请输入内容"/>
      </el-form-item>
      <el-form-item label="备注" prop="remarks">
        <el-input v-model="form.remarks" type="textarea" :rows="8" maxlength="64" show-word-limit
                  placeholder="请输入内容"/>
      </el-form-item>
    </el-form>
  </div>
</template>

<script>
import {getServer} from "@/api/oa/server";
import building from "../building";
import organization from "../organization";
import constructionBatch from "../constructionBatch";
import manufacturer from "../manufacturer";
import nvr from "../nvr";

export default {
  name: "ServerForm",
  dicts: ['DICT115'],
  components: {
    building,
    organization,
    constructionBatch,
    manufacturer,
    nvr
  },
  props: {
    serverId: {
      type: Number,
      default: undefined
    }
  },
  data() {
    return {
      // 表单参数
      form: {},
    }
  },
  created() {
    this.getInfo()
  },
  methods: {
    getInfo() {
      getServer(this.serverId).then(response => {
        this.form = response.data;
      });
    }
  }
}
</script>

<style scoped>

</style>